@@ -306,20 +306,20 @@ class Client:
     def import_annotation(self, item_id: int, payload: Dict[str, Any]) -> None:
         """
         Imports the annotation for the item with the given id.
-        
+
         Parameters
         ----------
         item_id: int
             Identifier of the Image or Video that we are import the annotation to.
         payload: Dict[str, Any]
-            A dictionary with the annotation to import. The default format is: 
+            A dictionary with the annotation to import. The default format is:
             `{"annotations": serialized_annotations, "overwrite": "false"}`
         """
         self._post_raw(f"/dataset_items/{item_id}/import", payload=payload)
 
     def fetch_remote_attributes(self, dataset_id: int) -> List[Dict[str, Any]]:
         """
-        Fetches all attributes remotly.
+        Fetches all attributes remotely.
 
         Parameters
         ----------
@@ -330,7 +330,7 @@ class Client:
         Returns
         -------
         List[Dict[str, Any]]
-            A List with the attributes. where each attribute is a dictionary.
+            A List with the attributes, where each attribute is a dictionary.
         """
         response: List[Dict[str, Any]] = cast(List[Dict[str, Any]], self._get(f"/datasets/{dataset_id}/attributes"))
         return response
@@ -725,7 +725,7 @@ class Client:
         workflow_id: int
             The id of the workflow that will receive the comment.
         text: str
-            The comment itself. 
+            The comment itself.
         x: float, default: 1
             The top left X coordinate value of the comment box.
         y: float, default: 1
@@ -762,12 +762,12 @@ class Client:
         ----------
         item_id: int
             The id of the item to be instantiated.
-        
+
         Returns
         -------
         int
             The id of the workflow for the given item.
-        
+
         Raises
         ------
         ValueError
@@ -1080,7 +1080,7 @@ class Client:
                 raise InsufficientStorage()
 
     def _has_json_response(self, response: Response) -> bool:
-        return response.headers.get("content-type") == "application/json"
+        return "application/json" in response.headers.get("content-type", "")
 
     def _get_response_debug_text(self, response: Response) -> str:
         if self._has_json_response(response):
