@@ -47,7 +47,7 @@ class Split:
     Attributes
     ----------
     random: Optional[Dict[str, Path]], default: None
-        Stores the type of split (e.g.: ``train``, ``val``, ``test``) and the file path where the 
+        Stores the type of split (e.g.: ``train``, ``val``, ``test``) and the file path where the
         split is stored if the split is of type ``random``. Defaults to ``None``.
     stratified: Optional[Dict[str, Dict[str, Path]]], default: None
         Stores the relation between an annotation type and the partition-filepath key value of the
@@ -61,10 +61,10 @@ class Split:
         """
         Returns whether or not this split instance is valid.
 
-        Returns 
+        Returns
         -------
         bool
-            ``True`` if this isntance is valid, ``False`` otherwise.
+            ``True`` if this instance is valid, ``False`` otherwise.
         """
         return self.random is not None or self.stratified is not None
 
@@ -310,7 +310,11 @@ def _stratify_samples(
     X_train = np.concatenate((X_train, np.array(single_files)), axis=0)
     X_val, X_test, y_val, y_test = _remove_cross_contamination(
         *train_test_split(
-            X_tmp, y_tmp, test_size=(test_size / (val_size + test_size)), random_state=split_seed, stratify=y_tmp,
+            X_tmp,
+            y_tmp,
+            test_size=(test_size / (val_size + test_size)),
+            random_state=split_seed,
+            stratify=y_tmp,
         ),
         test_size,
     )
@@ -322,7 +326,11 @@ def _stratify_samples(
 
 
 def _remove_cross_contamination(
-    X_a: np.ndarray, X_b: np.ndarray, y_a: np.ndarray, y_b: np.ndarray, b_min_size: int,
+    X_a: np.ndarray,
+    X_b: np.ndarray,
+    y_a: np.ndarray,
+    y_b: np.ndarray,
+    b_min_size: int,
 ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
     """
     Remove cross contamination present in X_a and X_b by selecting one or the other on a flip coin decision.
